@@ -73,6 +73,10 @@ class FeedManager(object):
         self.conf_storage = FeedConfStorage(self.conf_path, pattern=pattern)
         if dateparser:
             def dateparser_tuple_parser(string):
+                if string.endswith('-0000'):
+                    # workaround bug https://github.com/scrapinghub/dateparser/issues/548
+                    # replace the last '-0000' with '+0000' by reversing the string twice
+                    string = string[::-1].replace('-0000'[::-1], '+0000'[::-1], 1)[::-1]
                 return dateparser.parse(string).utctimetuple()
             feedparser.registerDateHandler(dateparser_tuple_parser)
 
@@ -343,8 +347,8 @@ class Feed(feedparser.FeedParserDict):
             item['updated_parsed'] = pick_first_date()
 
         if not item.get('updated_parsed'):
-            logging.warning('no parseable date found in feed item %s from feed %s, using current time instead',
-                            item.get('id'), self.get('url'))
+            logging.info('no parseable date found in feed item %s from feed %s, using current time instead',
+                         item.get('id'), self.get('url'))
             item['updated_parsed'] = datetime.utcnow().timestamp()
 
         # 2. add UID if missing (issue #112)
